#
# Cookbook Name:: guacamole
# Recipe:: default
#
# Copyright (c) 2016 The Authors, All Rights Reserved.

# Add hostname and ip address to host file
template '/etc/hosts' do
	source 'hosts.erb'
end

# Update apt database
apt_update 'Update the apt cache daily' do
  frequency 86_400
  action :periodic
end

# Install Guacamole depencies
package 'libcairo2-dev'
package 'libjpeg62-dev'
package 'libpng12-dev'
package 'libossp-uuid-dev'
package 'libfreerdp-dev'
package 'libpango1.0-dev'
package 'libssh2-1-dev'
package 'libtelnet-dev'
package 'libvncserver-dev'
package 'libpulse-dev'
package 'libssl-dev'
package 'libvorbis-dev'
package 'libwebp-dev'
package 'tomcat7'

service "tomcat" do
  action :stop
end

guacamoleserver_filename = 'guacamole-server-0.9.9.tar.gz'
guacamoleclient_filename = 'guacamole.war'
guacamoleserver_path = Chef::Config[:file_cache_path] + '/' + guacamoleserver_filename
guacamoleclient_path = '/var/lib/tomcat7/webapps/' + guacamoleclient_filename

remote_file guacamoleserver_path do
	source 'http://sourceforge.net/projects/guacamole/files/current/source/guacamole-server-0.9.9.tar.gz'
end

remote_file guacamoleclient_path do
	source 'http://sourceforge.net/projects/guacamole/files/current/binary/guacamole-0.9.9.war'
end

execute 'Untar Guacamole server source' do
  cwd Chef::Config[:file_cache_path]
  command 'tar xzvf ' + guacamoleserver_filename
end

execute 'Configure Guacamole source' do
  cwd Chef::Config[:file_cache_path] + '/guacamole-server-0.9.9'
  command './configure --with-init-dir=/etc/init.d'
end

execute 'Configure Guacamole source' do
  cwd Chef::Config[:file_cache_path] + '/guacamole-server-0.9.9'
  command 'make'
end

execute 'Configure Guacamole source' do
  cwd Chef::Config[:file_cache_path] + '/guacamole-server-0.9.9'
  command 'sudo make install'
end

execute 'Configure Guacamole source' do
  cwd Chef::Config[:file_cache_path] + '/guacamole-server-0.9.9'
  command 'sudo update-rc.d guacd defaults'
end

execute 'Configure Guacamole source' do
  cwd Chef::Config[:file_cache_path] + '/guacamole-server-0.9.9'
  command 'sudo ldconfig'
end

directory '/etc/guacamole' do
	action :create
end

template '/etc/guacamole/user-mapping.xml' do
	source 'user-mapping.xml.erb'
end

template '/etc/guacamole/guacamole.properties' do
	source 'guacamole.properties.erb'
end

template '/usr/share/tomcat7/bin/setenv.sh' do
	source 'setenv.sh.erb'
end

service 'guacd' do
	action [:enable, :start]
end

service "tomcat7" do
  action :start
end

reboot 'Reboot' do
	action :request_reboot
end